@@ -24,6 +24,10 @@ class FeedConfig:
     source: str
     enable: bool = True
     save_bandwith: bool = True
+    only_today: bool = False
+    users: List[int] = attr.ib(factory=list)
+    channels: List[int] = attr.ib(factory=list)
+    groups: List[int] = attr.ib(factory=list)
     notification: Optional[bool] = None
     etag: Optional[str] = None
     modified: Optional[str] = None
@@ -35,6 +39,9 @@ class FeedConfig:
     def __str__(self):
         return self.name
 
+    def get_chat_ids(self) -> List[int]:
+        return self.users + self.channels + self.groups
+
 
 @attr.dataclass
 class Config:
@@ -50,6 +57,7 @@ class Config:
     template_data: dict = attr.ib(default=TEMPLATE_DATA)
     users: List[int] = attr.ib(factory=list)
     channels: List[int] = attr.ib(factory=list)
+    groups: List[int] = attr.ib(factory=list)
     feeds: List[FeedConfig] = attr.ib(factory=list)
 
     def __attrs_post_init__(self) -> None:
@@ -72,6 +80,9 @@ class Config:
                 self._template = Template(f.read())
         logger.debug(f"Loaded config {self}")
 
+    def get_chat_ids(self) -> List[int]:
+        return self.users + self.channels + self.groups
+
     @property
     def template(self) -> Template:
         return self._template
