@@ -1,3 +1,4 @@
+from .img import Img
 from .entry import Entry
 from .channel import Channel
 from .feed import Feed
@@ -5,6 +6,7 @@ from .updater import FeedUpdater
 
 
 __all__ = [
+    "Img",
     "Entry",
     "Channel",
     "Feed",
